;
;----------------------------------------------------------------------
;
; ========================================================
;
;       GB60.asm:        AXIOM M68EVB08GB60 
;                                   
;         Version:       1.0   Released 01/28/2003
;          Author:       Gary Karnes , Axiom Manufacturing
;        Compiler:       HC08
;        Platform:       AXIOM M68EVB08GB60 AXM-0308 
;        Purpose:        Main Program
; ========================================================

;	 
;
;----------------------------------------------------------------------
            	XDEF	IRQ
            	XDEF	Reset

;	    	XREF	INIT_IO


;--------------------------------------------
; import register and peripheral memory map
;--------------------------------------------
	  include gb60_io.asm
	
;--------------------------------------------
; Constant
;--------------------------------------------
;CR:		EQU	$0d		; hex carriage return character
;LF:		EQU	$0A		; hex line feed character
;NUL:		EQU	$00		; ascii null character, end of string

;--------------------------------------------
; Interrupt vectors
;--------------------------------------------
IRQ:         EQU     $182C           ; Irq interrupt vector
initStack:   equ    $107f       ; top of ram
					  ; bottom of the 2nd flash module
					
;--------------------------------------------
; Data space for direct addressing mode...
;--------------------------------------------
            ORG  $80		; Bottom of GB60 RAM module

Tmp:		DS.B	1	; temp use register
Tmp1:		DS.B	1	; temp use register
counter:    	DS.B  	1	; temp use counter


;---------------------------------------------
; Start rom space ...
;---------------------------------------------
            ORG  $182C		; Program starts at bottom of 2nd flash module
;---------------------------------------------
; Initialize MCU
;---------------------------------------------
Reset:
; Setup Stack
            ldhx    #initStack  ; initialize stack
            txs                 ; transfer to stack
          lda   #$53            ; disable cop
          sta   SIMOPT
          jsr   Set_308         ; setup board


         
  


          CLI
	    nop
;
;-------------------------------------		
; Main scheduler code here		
;-------------------------------------
Main:
;        LDHX    #HelloStr       ; Point to string
;        jsr     Send_MSG        ; send string to serial port

        jsr     LCD_T2PP        ; set up LCD

        jsr     Menu            ; display menu

Echo:
        jsr     INPUT           ; Get input from user
        cmp     #'1'            
        bne     MainN1
        jsr     Ana_308         ; Test Analog
        bra     Main
MainN1:
        cmp     #'2'            
        bne     MainN2
        jsr     Buz_308         ; Buzzer Test
         
        bra     Main


MainN2:
        cmp     #'3'            ; Com2 Test
        bne     MainN3
        jsr     Com2_308  
        bra     Main

MainN3:
        cmp     #'4'            ; Dip Switch?
        bne     MainN4
        jsr     Dip_308         ; Test Dip Switch
        bra     Main
;
MainN4:
        cmp     #'5'            ; 
        bne     MainN5
        jsr     Irq_308         ; 
        bra     Main

MainN5:

        cmp     #'6'            ; 
        bne     MainN6
        jsr     Key_308         ; 
        bra     Main

MainN6:
        cmp     #'7'            ; 
        bne     MainN7
        jsr     LCD_Tst          ; 
        bra     Main

MainN7:
        cmp     #'8'
        bne     MainN8
        jsr     LEDS_308
        bra     Main

MainN8:
        cmp     #'9'
        bne     MainN9
        jsr     Pwr_308
        bra     Main
MainN9:


;
; set to upper case
        and     #$5F
        cmp     #'A'
        bne     MainNA
        jsr     BUT_308
        bra     Main

MainNA:

        cmp     #'B'
        bne     MainNB
        jsr     RV1_308
        bra     Main

MainNB:
        cmp     #'C'
        bne     MainNC
        jsr     S485_308
        bra     Main
MainNC:

        cmp     #$0D
        beq     Main



        bra     Main


	  jsr	    Sci1_Out	  ; echo choice
        bra     Echo            ; repeat
;-------------------------------------
; constants and text strings here...
;-------------------------------------
HelloStr:
;        DC  CR
;        DC  LF
        DC  "Press a Key, you will see the echo"
;	  DC	CR
;        DC	LF
;        DC	NUL       ; end of message


;            ORG  $FFFE
;        DC.W      Entry           ; reset vector

;
      include    Set_308.asm        ; set up file
      include    Osc_308.asm        ; oscillator control
      include    Sci_308.asm        ; Sci control
      include    LCD_308.asm        ; LCD driver
      include       Menu.asm        ; Menu
      include    Del_308.asm        ; Delay
      include     String.asm        ; String functions
      include    Message.asm        ; Messages
      include   Key_308.asm        ; Keypad
      include    Buz_308.asm        ; Buzzer Test
      include    Dip_308.asm        ; Dip Switch Test
      include   Com2_308.asm        ; Com2 Test
      include   LEDS_308.asm        ; LEDS Test
      include    BUT_308.asm        ; Buttons Test
      include    RV1_308.asm        ; RV1 Test
      include    HEX_308.asm        ; Hex routines 
      include    Ana_308.asm        ; analog Routine 
      include    Pwr_308.asm        ; Power Check
      include   S485_308.asm        ; 422 and 485 loop back
      include    Irq_308.asm        ; Irq Interrupt
      include    Vectors.asm        ; interrupt vectors
;

         
        END
