;
* =============================================================
*
*   SelfAnal.asm    Axiom Analog Driver for the Motorola Hc12 
*                                 
*   Version:        1.0   Released 8/30/2002
*   Author:         Gary Karnes , Axiom Mfg.
*   Compiler:       As12
*       
*   Platform:       Axiom CML12S
*   Purpose:        Analog Subroutines
* 
* ===============================================================
;
;  Analog Subroutines
;  
;  SelfAnal  = Does a Self Test on the analog channels
;  AnRdCh0   =  read analog channel zero
;  AnRdCh1   =   "      "     "     one
;  AnRdCh2   =   "      "     "     two 
;  AnRdCh3   =   "      "     "     three
;  AnRdCh4   =   "      "     "     four
;  AnRdCh5   =   "      "     "     five
;  AnRdCh6   =   "      "     "     six
;  AnRdCh7   =   "      "     "     seven
;  AnRdCh8   =   "      "     "     eight
;  AnRdCh9   =   "      "     "     nine
;  AnRdCh10  =   "      "     "     ten 
;  AnRdCh11  =   "      "     "     eleven
;  AnRdCh12  =   "      "     "     twelve
;  AnRdCh13  =   "      "     "     thirteen
;  AnRdCh14  =   "      "     "     fourteen
;  AnRdCh15  =   "      "     "     fifteen
;
;[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[
; 
; Analog Selftest
; This subroutine will test the analog port
; This uses a header installed in the analog
; port with 10k resistors between VRH to each 
; analog channel then to VRL
;
; Normal reading in D
;    Ch0  = $01F5
;    Ch1  = $022B
;    Ch2  = $0273
;    Ch3  = $02B9
;    Ch4  = $02F5
;    Ch5  = $033B
;    Ch6  = $037C
;    Ch7  = $03BE
;    Ch8  = $01C0
;    Ch9  = $0185
;    Ch10 = $014B
;    Ch11 = $0116
;    Ch12 = $00DA
;    Ch13 = $00A7
;    Ch14 = $006F
;    Ch15 = $0037
;
;    Acc B = Channel
;        X = Compare value
;        Y = high limit
SelfAnal:
            jsr   M_CRLF
            jsr   M_CRLF
            jsr   M_CRLF
            jsr   String3
            fdb   MAnalog         ; Analog Self Test
            fdb   MSelf
            fdb   MTest
            jsr   String4
            fdb   MRev            ; Rev E and later
            fdb   M_E
            fdb   Mand
            fdb   MLater
            jsr   M_CRLF
            jsr   String3
            fdb   MInstall        ; Install Test Connector
            fdb   MTest
            fdb   MConnect
            jsr   String3
            fdb   Mon             ; on Analog Port
            fdb   MAnalog
            fdb   MPort
            jsr   M_CRLF
            jsr   PKEY            ; press any key
            jsr   Input
            

; display values
;            jsr   SelfADY         ; display values



; Start Checking Analog Channel
; Check Channel zero 
;
           
            jsr   AnRdCh0         ; read channel zero
            ldy   #$0000          ; channel zero
            ldx   #$01F5          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel one
            jsr   AnRdCh1         ; read channel zero
            ldy   #$0001          ; channel zero
            ldx   #$022B          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel two
            jsr   AnRdCh2         ; read channel zero
            ldy   #$0002          ; channel zero
            ldx   #$0273          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel three
            jsr   AnRdCh3         ; read channel zero
            ldy   #$0003          ; channel zero
            ldx   #$02B9          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed
; Check Channel four
            jsr   AnRdCh4         ; read channel zero
            ldy   #$0004          ; channel zero
            ldx   #$02F5          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel five
            jsr   AnRdCh5         ; read channel zero
            ldy   #$0005          ; channel zero
            ldx   #$033B          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel six
            jsr   AnRdCh6         ; read channel zero
            ldy   #$0006          ; channel zero
            ldx   #$037C          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed
; Check Channel seven
            jsr   AnRdCh7         ; read channel zero
            ldy   #$0007          ; channel zero
            ldx   #$03BE          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel eight
            jsr   AnRdCh8         ; read channel zero
            ldy   #$0008          ; channel zero
            ldx   #$01C0          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel nine
            jsr   AnRdCh9         ; read channel zero
            ldy   #$0009          ; channel zero
            ldx   #$0185          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed
; Check Channel ten
            jsr   AnRdCh10         ; read channel zero
            ldy   #$000A          ; channel zero
            ldx   #$014B          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel eleven
            jsr   AnRdCh11         ; read channel zero
            ldy   #$000B          ; channel zero
            ldx   #$0116          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel twelve
            jsr   AnRdCh12         ; read channel zero
            ldy   #$000C          ; channel zero
            ldx   #$00DA          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel thirteen
            jsr   AnRdCh13         ; read channel zero
            ldy   #$000D          ; channel zero
            ldx   #$00A7          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed

; Check Channel fourteen
            jsr   AnRdCh14        ; read channel zero
            ldy   #$000E          ; channel zero
            ldx   #$006F          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed
; Check Channel fifteen
            jsr   AnRdCh15         ; read channel zero
            ldy   #$000F          ; channel zero
            ldx   #$0037          ; Compare value
            jsr   SelfAnCp        ; go check channel
            lbcs   SelfAnQ1        ; quit if failed
; Report Passed
            jsr   M_CRLF           ; new line
            jsr   M_CRLF
            jsr   String1
            fdb   MPassed          ; Passed
            jsr   PKEY             ; press any key
            jsr   Input
SelfAnQ1:
            rts
;


;
;===============================================
; Test Code if you want the values printed
; test channel 0
SelfADY:
            jsr   String2
            fdb   MCh0            ; Ch0 = 
            fdb   MequalSy
            jsr   AnRdCh0         ; read channel zero
            jsr   HEX4D
            jsr   M_CRLF
; test channel 1
            jsr   String2
            fdb   MCh1            ; Ch1 =
            fdb   MequalSy
            jsr   AnRdCh1         ; read channel zero
            jsr   HEX4D           ; output hex
            jsr   M_CRLF

; test channel 2
            jsr   String2
            fdb   MCh2
            fdb   MequalSy
            jsr   AnRdCh2         ; 
            jsr   HEX4D           ; output hex
            jsr   M_CRLF

; test channel 3
            jsr   String2
            fdb   MCh3           ; Ch3 = 
            fdb   MequalSy
            jsr   AnRdCh3        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF

; test channel 4
            jsr   String2
            fdb   MCh4           ; Ch4 =
            fdb   MequalSy
            jsr   AnRdCh4        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF


; test channel 5
            jsr   String2
            fdb   MCh5           ; Ch5 =
            fdb   MequalSy 
            jsr   AnRdCh5        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF


; test channel 6
            jsr   String2
            fdb   MCh6           ; Ch6 =
            fdb   MequalSy 

            jsr   AnRdCh6        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF

; test channel 7
            jsr   String2
            fdb   MCh7           ; Ch7 =
            fdb   MequalSy 

            jsr   AnRdCh7        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF

; test channel 8
            jsr   String2
            fdb   MCh8           ; Ch8 =
            fdb   MequalSy 

            jsr   AnRdCh8        ; 
            jsr   HEX4D          ; output hex
            jsr   M_CRLF

; test channel 9
            jsr   String2
            fdb   MCh9           ; Ch9 =
            fdb   MequalSy 

            jsr   AnRdCh9      ; 
            jsr   HEX2         ; output hex
            tba
            jsr   HEX2
            jsr   M_CRLF

; test channel 10
            jsr   String2
            fdb   MCh10           ; Ch10 =
            fdb   MequalSy 

            jsr   AnRdCh10      ; 
            jsr   HEX2         ; output hex
            tba
            jsr   HEX2
            jsr   M_CRLF

; test channel 11
            jsr   String2
            fdb   MCh11           ; Ch11 =
            fdb   MequalSy 

            jsr   AnRdCh11      ; 
            jsr   HEX4D        ; output hex
            jsr   M_CRLF

; test channel 12
            jsr   String2
            fdb   MCh12           ; Ch12 =
            fdb   MequalSy 

            jsr   AnRdCh12      ; 
            jsr   HEX4D         ; output hex
            jsr   M_CRLF

; test channel 13
            jsr   String2
            fdb   MCh13           ; Ch13 =
            fdb   MequalSy 

            jsr   AnRdCh13      ; 
            jsr   HEX4D         ; output hex
            jsr   M_CRLF

; test channel 14
            jsr   String2
            fdb   MCh14           ; Ch14 =
            fdb   MequalSy 

            jsr   AnRdCh14      ; 
            jsr   HEX4D         ; output hex
            jsr   M_CRLF


; test channel 15
            jsr   String2
            fdb   MCh15           ; Ch15 =
            fdb   MequalSy 

            jsr   AnRdCh15      ; 
            jsr   HEX4D         ; output hex
            jsr   M_CRLF


            jsr   Input

            rts
;===========================================

;]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]
;
;[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[
;
; The following will read a analog channel
; and mask off unused bits
;
; Read Analog zero
AnRdCh0:
            ldd    ADR00H    ; get results
            bra    AnMask
;
; Read channel 1
AnRdCh1:
            ldd    ADR01H    ; get results
            bra    AnMask
;
; Read Channel 2
AnRdCh2:
            ldd    ADR02H    ; get results
            bra    AnMask
;
; Read Channel 3
AnRdCh3:
            ldd    ADR03H    ; get results
            bra    AnMask
;
; Read Channel 4
AnRdCh4:
            ldd    ADR04H    ; get results
            bra    AnMask
;
; Read Channel 5
AnRdCh5:
            ldd    ADR05H    ; get results
            bra    AnMask
;
; Read Channel 6
AnRdCh6:
            ldd    ADR06H    ; get results
            bra    AnMask
;
; Read Channel 7
AnRdCh7:
            ldd    ADR07H    ; get results
            bra    AnMask
;
; Read Channel 8
AnRdCh8:
            ldd    ADR10H    ; get results
AnMask:
            anda   #$03
            rts
;
; Read Channel 9
AnRdCh9:
            ldd    ADR11H    ; get results
            bra    AnMask
;
; Read Channel 10
AnRdCh10:
            ldd    ADR12H    ; get results
            bra    AnMask
;
; Read Channel 11
AnRdCh11:
            ldd    ADR13H    ; get results
            bra    AnMask    ; 
;
; Read Channel 12
AnRdCh12:
            ldd    ADR14H    ; get results
            bra    AnMask    ;            
;
; Read Channel 13
AnRdCh13:
            ldd    ADR15H    ; get results
            bra    AnMask
;
; Read Channel 14
AnRdCh14:
            ldd    ADR16H    ; get results
            bra    AnMask
;
; Read Channel 15
AnRdCh15:
            ldd    ADR17H    ; get results
            bra    AnMask
;
;]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]] 
;
;=============================================
; This Subroutine will compare the limits
;       D = Value read
;       X = Normal value
;       Y = Channel
;       limit is set at $0030 above and below the normal value
SelfAnCp:
; set up stack with needed values
            pshy             ; save channel        8,sp
            pshx             ; save compare value  6,sp 
            pshd             ; save Read Value     4,sp
            pshd             ; setup low limit     2,sp
            pshd             ; setup high limit    0,sp
; set low limit
            ldd  6,sp        ; get compare value
            subd #$0030      ; get low limit
            bhs  SelfAnC1    ; skip if not zero
            ldd  #$0000      ; set low limit to zero
SelfAnC1: 
            std  2,sp        ; store low limit

; set high limit
            ldd  6,sp        ; get compare value
            addd #$0030      ; add the limit
            std  0,sp        ; save high limit
; check low limit
            ldd  4,sp        ; get read value
            cmpd 2,sp        ; compare to low limit
            blo  SelfAFl     ; report fail
            cmpd 0,sp        ; compare to high limit
            bhi  SelfAFl     ; report fail
            clc              ; report pass
            bra  SelfAnR     ; go to return path 
;
; report the fail here
SelfAFl:
            jsr   M_CRLF     ; new line
            jsr   M_CRLF     ; new line
            jsr   String1
            fdb   MCh
            ldaa  9,sp       ; get channel number
            jsr   HEXOUT
            jsr   String3
            fdb   MSpace1    ; space over
            fdb   MequalSy
            fdb   MFailed    ; 
            jsr   String3
            fdb   MSpace5
            fdb   MRead      ; Read =
            fdb   MequalSy 
            ldd   4,sp       ; get read value
            jsr   HEX4D       ; output D

            jsr   String3
            fdb   MSpace5
            fdb   MNormal      ; Normal =
            fdb   MequalSy 
            ldd   6,sp       ; get read value
            jsr   HEX4D       ; output D
            jsr   M_CRLF  
            jsr   PKEY        ; press any key to continue
            




            jsr   Input      ; wait for operator
            sec              ; report fail

; return path, remove stacked data
SelfAnR:
            leas   $0A,sp
            rts
;
;



;
;