;
;
; ========================================================
;
;     String.asm:        AXIOM M68EVB08GB60 
;                                   
;         Version:       1.0   Released 01/28/2003
;          Author:       Gary Karnes , Axiom Manufacturing
;        Compiler:       HC08
;        Platform:       AXIOM M68EVB08GB60 AXM-0308 
;        Purpose:        String Control
;      
; ========================================================
; 
;&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
;=========================================================
; Sci1 String 
;    Subroutines
;        Sci1STRP = Send string to LCD
;        Sci1ST1S = Gets address of string & calls LCDSTRP
;        Sci1STR1 = Sends one string, calls LCDSTR1SP
;        Sci1STR2 = Sends two strings, calls LCDSTR1SP
;        Sci1STR3 = Sends three strings, calls LCDSTR1SP
;=========================================================
; Send a String to the Sci1
; Index register H:X is loaded with address of string.
; continue until reading a zero.
Sci1STRP:
          lda     0,x         ; load byte from string
          beq     Sci1LSEP     ; if zero then end
          pshh                ; save h
          pshx                ; save x
       
          jsr     Sci1_Out    ; send character to Sci1
          pulx                ; restore x
          pulh                ; restore H
;          incx
          aix     #1          ; add one lx
          bra     Sci1STRP    ; repeat until end of string         
;          bne     Sci1STRP     ; if not zero then repeat
; increment H because X = 0
; using acc A
;          pshh
;          pula
;          inca
;          psha
;          pulh 
Sci1LSEP   lda     #$20        ; add space
          jsr     Sci1_Out
          rts
;========================
;========================
; Send one string to Sci1
; load 16 bit pointer after jsr
; sends space after string
; Sci1str1S is called from sub,sub
; example:
;           stack
;           sp = next available address
;           sp + 1 = Sci1STR1 return PC
;           sp + 3 = PC of programmed that called LCDSTR1
;
Sci1ST1S:
;         
;          ldhx     3,sp     ; get PC
           fcb   $9e,$fe,$03 ; ldhx not in assembler
;
           lda      0,x      ; get H high order string address
           psha              ; save on stack
           aix      #1        ; increment to low order string address
           lda      0,x      ; get x
           psha              ; save on stack
           aix      #1        ; adjustment PC

;          sthx     5,sp     ; save adjusted PC
          fcb      $9e,$ff,$05 ; sthx not in assembler
         
          
         
          pulx              ; get string low byte
          pulh              ; get string high byte
          jsr     Sci1STRP  ; send string
          rts
;
; Send a string to Sci1 
; address of string after call sub
; example:
;          jsr  Sci1STR1
;          fdb  Axiom
;.....................
Sci1Str1:
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;
; Send two strings to Sci1
; address of string after call sub
; example:
;          jsr  Sci1STR2
;          fdb  Axiom
;          fdb  Is
;....................
Sci1Str2:
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;===================
;
; Send three strings to Sci1
; address of string after call sub
; example:
;          jsr  Sci1STR3
;          fdb  Axiom
;          fdb  Is
;          fdb  Great
;....................
Sci1Str3:
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;
;===================
;
; Send four strings to Sci1
; address of string after call sub
; example:
;          jsr  Sci1STR4
;          fdb  Axiom
;          fdb  Manufact
;          fdb  is
;          fdb  Great
;....................
Sci1Str4:
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;===================
;
;
; Send five strings to Sci1
; address of string after call sub
; example:
;          jsr  Sci1STR5
;          fdb  Axiom
;          fdb  Manufact
;          fdb  is
;          fdb  Great
;          fdb  Company
;....................
Sci1Str5:
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;
;===================
;
;
;
; Send six strings to Sci1
; address of string after call sub
; example:
;          jsr  Sci1STR6
;          fdb  Axiom
;          fdb  Manufact
;          fdb  is
;          fdb  Great
;          fdb  Company
;          fdb  Service
;....................
Sci1Str6:
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          jsr     Sci1ST1S  ; send one string + space
          rts
;
;



;&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
;=========================================================
; LCD String 
;    Subroutines
;        LCDSTRP = Send string to LCD
;       LCDST1SP = Gets address of string & calls LCDSTRP
;        LCDSTR1 = Sends one string, calls LCDSTR1SP
;        LCDSTR2 = Sends two strings, calls LCDSTR1SP
;        LCDSTR3 = Sends three strings, calls LCDSTR1SP
;=========================================================
; Send a String to the LCD
; Index register H:X is loaded with address of string.
; continue until reading a zero.
LCDSTRP:
          lda     0,x         ; load byte from string
          beq     LCDLSEP     ; if zero then end
          pshh                ; save h
          pshx                ; save x
       
          jsr     LCD2PP_O    ; send character to lcd
          pulx                ; restore x
          pulh                ; restore H
;          incx
          aix      #1         ; increment hx
          bra      LCDSTRP    ; repeat until done
;          bne     LCDSTRP     ; if not zero then repeat
; increment H because X = 0
; using acc A
;          pshh
;          pula
;          inca
;          psha
;          pulh 
LCDLSEP   lda     #$20        ; add space
          jsr     LCD2PP_O
          rts
;========================
;========================
; Send one string to Lcd
; load 16 bit pointer after jsr
; sends space after string
; Lcdstr1SP is called from sub,sub
; example:
;           stack
;           sp = next available address
;           sp + 1 = LCDSTR1 return PC
;           sp + 3 = PC of programmed that called LCDSTR1
;
LCDST1SP:
;         
;          ldhx     3,sp     ; get PC
           fcb   $9e,$fe,$03 ; ldhx not in assembler
;
           lda      0,x      ; get H high order string address
           psha              ; save on stack
           aix      #1        ; increment to low order string address
           lda      0,x      ; get x
           psha              ; save on stack
           aix      #1        ; adjustment PC

;          sthx     5,sp     ; save adjusted PC
          fcb      $9e,$ff,$05 ; sthx not in assembler
         
          
         
          pulx              ; get string low byte
          pulh              ; get string high byte
          jsr     LCDSTRP  ; send string
          rts
;
; Send a string to LCD 
; address of string after call sub
; example:
;          jsr  LCDSTR1
;          fdb  Axiom
;.....................
LCDSTR1:
          jsr     LCDST1SP  ; send one string + space
          rts
;
;
; Send two strings to LCD
; address of string after call sub
; example:
;          jsr  LCDSTR2
;          fdb  Axiom
;          fdb  Is
;....................
LCDSTR2:
          jsr     LCDST1SP  ; send one string + space
          jsr     LCDST1SP  ; send one string + space
          rts
;
;===================
;
; Send three strings to LCD
; address of string after call sub
; example:
;          jsr  LCDSTR3
;          fdb  Axiom
;          fdb  Is
;          fdb  Great
;....................
LCDSTR3:
          jsr     LCDST1SP  ; send one string + space
          jsr     LCDST1SP  ; send one string + space
          jsr     LCDST1SP  ; send one string + space
          rts
;
;===================

;
;
;

