;
; ==================================================
;
;   Key_308.asm     Axiom M68EVB08GB60 
;                                 
;   Version:        1.0   Released 02/12/2003
;   Author:         Gary Karnes , Axiom Mfg.
;   Compiler:       HC08
;       
;   Platform:       Axiom M68EVB08GB60 AXM-0308
;   Purpose:        Keypad Port
; ==================================================
;
; 
;
;
; Subroutines for setup and reading keypad
;
;  Key_308.ASM   KeyPad Test
;  Key308_I      Initilize port
;  Key308_G      get key
;  Key308_W      wait for key
;  Key308_S      scan for key
;  Key308_R      key reset
;  Key308_D      delay wait for lines to settle
;  ---------
;  KEYPAD routines for Axiom HC08 development boards.
;  KEYPAD uses Port A.
;
;  Variables - calling program must reserve these:
;  -----------
;     Global variables
;  	
;     Local variables
;	
; Define Key Character Table
;
Key_Tbl:  FCC  'A321B654C987D#0*'
;
;
; key pad test
Key_308:
            jsr   Sci1Str4
            fdb   MCRLF
            fdb   MCRLF
            fdb   MKeyPad
            fdb   MTest
            mov   #$ff,PTAPE    ; enable pull ups
            mov   #$00,PTADD    ; all inputs
            jsr   DELAY1MS      ; delay
            lda   PTAD          
            cmpa  #$ff          ; verfiy results
            bne   Key308_F
; check 55
            mov   #$55,PTADD
            mov   #$AA,PTAD     ; set low
            jsr   DELAY1MS
            lda   PTAD
            cmpa  #$AA
            bne   Key308_F       ; report fail  
; check AA
            mov   #$aa,PTADD
            mov   #$55,PTAD
            mov   #$ff,PTAPE     ; enable pull up
            jsr   DELAY1MS
            lda   PTAD 

            cmpa  #$55
            bne   Key308_F
; check KeyPad Loop Back
            jsr   Sci1Str5
            fdb   MCRLF
            fdb   MCRLF
            fdb   MInstall
            fdb   MTest 
            fdb   MPlug
            jsr   Sci1Str1
            fdb   MOn 
            fdb   MKeyPad
            jsr   PKey 
; send zero
            mov   #$f0,PTADD
            mov   #$00,PTAD
            lda   PTAD
            cmpa  #$00
            bne   Key308_F
; send ones
            mov   #$f0,PTAD
            lda   PTAD
            cmpa  #$ff
            bne   Key308_F

            jsr   Passed
            rts
;
; Key Port failed
Key308_F:
            jsr   Failed       ; report failed
            rts
;
;-------
GETKEY:
	jsr	Key308_S		; scan keypad for new key
	tsta			; key pressed?
	beq	GETKEY		; loop if no
	rts

;-------
;
; Scan KEYPAD for input. return A=0 no input else A=key
; columns are active low, rows are then read active low
; Port A bits 0-3 drive the scan
;        bits 4-7 are pulled high, will go low if key is pressed
;
Key308_S:
         
Key308SR:
;         bset     PORTH,#$0F  ; set all KEYPAD columns
         mov      #$00,PTAD    ; drive lines low
         bsr      Key308_D     ; delay
         lda	PTAD	       ; get Keypad port
	   and	#$F0	       ; key mask bits 4-7
         cmp      #$F0         ; check any keys are pressed
	   beq	Key308_R	 ; branch if NO key pressed, 4-7 high

;-------
; here if a key is pressed, determine which one
K3_Scan1:
         mov      #$0f,PTAD   ; disable scan
         bclr     0,PTAD      ; enable column 1
         bsr      Key308_D    ; delay
;         ldh      #$00        ; clear row counter
	   jsr	K3_Scan2	; get KEYPAD row status
	   bne	K3_Row	; branch if a key pressed, find row

           bset    0,PTAD       ; disable column
           bclr    1,PTAD       ; enable column
;           ldh     #$04         ; next row count
           jsr	K3_Scan2	; get KEYPAD row status
           bne	K3_Row	; branch if a key pressed, find row


          
           bset    1,PTAD       ; disable column
           bclr    2,PTAD       ; enable column  
;           ldh     #$08         ; next row count
           jsr	K3_Scan2	; get KEYPAD row status
           bne	K3_Row	; branch if a key pressed, find row


          
           bset    2,PTAD      ; disable column
           bclr    3,PTAD      ; enable column
;           ldh     #$0c        ; next row count
           jsr	K3_Scan2	; get KEYPAD row status
           bne	K3_Row		; branch if a key pressed, find row
	     bra	Key308_R	; NO key pressed, reset

K3_Scan2:
           jsr	 Key308_D	; wait for lines to settle
	     lda	 PTAD		; get KEYPAD port
	     and	 #$F0		; key mask
           cmpa    #$F0        ; no keys? (all high)
           rts

; here if a key is pressed, h = column offset, A=row value
; two values are stored on the stack
K3_Row:
;         pshh                 ; column offset
          bsr     K3_Scan2     ; verify key still there
          beq     Key308_R     ; quit if no key
          ldhx    #Key_Tbl     ; load look up
K3_Row1:
	   lsla			 ; shift row value to low nibble
         bcc      K3_Row2      ; column found, go compute offset 
         aix      #1           ; increment offset count h:x
	   bra	K3_Row1		; loop
K3_Row2:
;
         lda      1,sp        ; get row offset       
;
K3_R2_N1:
	   beq      K3_R2_N      ; done 
         aix      #1           ; increment table pointer
         deca                  ; decrement count
         bne      K3_R2_N1  

K3_R2_N:
         ais      #$01        ; reset stack to normal
; key pressed in A, debounce
         lda      ,x          ; 
;	   ldab	#$04		; see if we already debounced this key
	   rts			; same key pressed, already said so, return it
KEYCOUNT:
	   rts			; return key
KEYNEW:
KEYNO:
         clra			; return no key pressed yet
	   rts
;-------
Key308_R:
	   mov      #$0f,PTAD	; reset scan high (inactive)
	   clra			; clear key status
	   rts
;-------
; Initilize GB60 port A (keypad port) for scanning keypad
;
Key308_I:
          mov  #$f0,PTAPE  ; pullups for 4-7
;          mov  #$00        ; set 0-3 low
          mov  #$0f,PTADD  ; 0-3 outputs, 4-7 inputs
          rts

;
; Delay for keypad bounce
;
Key308_D:
                pshx                    ;
                pshh                    ;

                ldhx    #$0100          ;
Key3_DL3:       aix     #-1             ;
                nop                     ;
                cphx    #0              ;
                bne     Key3_DL3        ;
                                        ;
                                        ;
                pulh                    ;
                pulx                    ;
                rts                     
;
;

